==> standwithukraine-1.3.7.tar.gz: standwithukraine/src/Form/StandWithUkraineFormBase.php <==
<?php

namespace Drupal\standwithukraine\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\standwithukraine\StandWithUkraineTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure StandWithUkraine settings for this site.
 */
abstract class StandWithUkraineFormBase extends ConfigFormBase implements TrustedCallbackInterface {

  use StandWithUkraineTrait;

  /**
   * The config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The cache.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cache;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);

    $instance->cache = $container->get('cache.default');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['standwithukraine.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'standwithukraine_' . $this->getName() . '_form';
  }

  /**
   * Returns form identifier central part and configuration record prefix.
   *
   * @return string
   *   The plain text.
   */
  abstract protected function getName();

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->cache->invalidate('standwithukraine');

    parent::submitForm($form, $form_state);
  }

  /**
   * Alter field structure.
   *
   * @param array $element
   *   An associative array containing the properties and children of the
   *   element.
   *
   * @return array
   *   The changed form element render array.
   */
  abstract public static function preRenderField(array $element);

  /**
   * Gets data from configuration object.
   *
   * @param string $key
   *   A string that maps to a key within the configuration data.
   *
   * @return mixed
   *   The data that was requested.
   */
  protected function read($key) {
    return $this->config->get($this->getName() . '.' . $key);
  }

}

==> standwithukraine-1.3.8.tar.gz: standwithukraine/src/Form/StandWithUkraineFormBase.php <==
<?php

namespace Drupal\standwithukraine\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\standwithukraine\Service\StandWithUkraineImageInterface;
use Drupal\standwithukraine\StandWithUkraineTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure StandWithUkraine settings for this site.
 */
abstract class StandWithUkraineFormBase extends ConfigFormBase implements TrustedCallbackInterface {

  use StandWithUkraineTrait;

  /**
   * The config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The cache.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cache;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);

    $instance->cache = $container->get('cache.default');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['standwithukraine.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'standwithukraine_' . $this->getName() . '_form';
  }

  /**
   * Returns form identifier central part and configuration record prefix.
   *
   * @return string
   *   The plain text.
   */
  abstract protected function getName();

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->cache->invalidate(StandWithUkraineImageInterface::CACHE . 'favicon');

    parent::submitForm($form, $form_state);
  }

  /**
   * Alter field structure.
   *
   * @param array $element
   *   An associative array containing the properties and children of the
   *   element.
   *
   * @return array
   *   The changed form element render array.
   */
  abstract public static function preRenderField(array $element);

  /**
   * Gets data from configuration object.
   *
   * @param string $key
   *   A string that maps to a key within the configuration data.
   *
   * @return mixed
   *   The data that was requested.
   */
  protected function read($key) {
    return $this->config->get($this->getName() . '.' . $key);
  }

}
